% Spherical Tumbler MATLAB Interface
% This is a sample program that demonstrates how to script the tumbler
% Written by Scott McLeod - June 9, 2009

% COM Port Setting
COM_PORT = 15;

% Output time so we can distinguish data/runs in MATLAB Command Window
clc
timeInfo = clock;
fprintf('Spherical Tumber MATLAB Interface\n');
fprintf('Date: %d/%d/%d   Time: %d:%d:%2.0f\n', timeInfo(2), timeInfo(3), timeInfo(1), timeInfo(4), timeInfo(5), timeInfo(6))

% Attempt to open the serial port if not already connnected
if (~exist('mySerialObj', 'var'))
    mySerialObj = MotorControllerConnect(COM_PORT);
end

% Check to make sure the serial object is writable
if (~strcmp(mySerialObj.status, 'open'))
    fprintf('***** ERROR: Could not open serial port object\n');
    fclose(mySerialObj);
    delete(instrfind)
    clear mySerialObj
    return
end

% If we got here, serial port should be openend and writeable
fprintf('Serial Port Sucessfully Opened and Connected.\n');

% Set up the slave PIC addresses -- DO NOT CHANGE
AXIS_MOTOR_ID = 0;
ROLL_MOTOR_ID = 1;

% Set current position to home position
% Note in general, you don't want to reset the home position as this
% will cumulate error in the position tracking.  Instead, it is better
% to perform the positions all relative to a single starting location.
mc_resetpos(AXIS_MOTOR_ID, mySerialObj);
mc_resetpos(ROLL_MOTOR_ID, mySerialObj);

% Set motor velocities
% This operation only has to be set once, but may be changed whenever
% All velocities should be entered as positive numbers (even for backwards
% motion)
set_mc_velocity(1, AXIS_MOTOR_ID, mySerialObj);
set_mc_velocity(10, ROLL_MOTOR_ID, mySerialObj);


% Now we can change the desired program actions
% set_mc_position commmands are sent with inputs:
% (# degrees, motor_id, serial object)

old_axis_angle = 0;
old_roll_angle = 0;

for iteration = 1:5
    fprintf('Iteration %d.\n', iteration);
    
    % Move axis motor and pause appropriately
    axis_angle = -90;
    set_mc_position(axis_angle, AXIS_MOTOR_ID, mySerialObj)
    pause (abs(axis_angle - old_axis_angle)/(360 * 1) * 60 + 1);
    old_axis_angle = axis_angle;
    
    % Move roll motor and pause appropriately
    roll_angle = 116;
    set_mc_position(roll_angle, ROLL_MOTOR_ID, mySerialObj);
    pause (abs(roll_angle - old_roll_angle)/(360 * 10) * 60 + 1);
    old_roll_angle = roll_angle;

    % Move roll motor and pause appropriately
    roll_angle = 90;
    set_mc_position(roll_angle, ROLL_MOTOR_ID, mySerialObj);
    pause (abs(roll_angle - old_roll_angle)/(360 * 10) * 60 + 1);
    old_roll_angle = roll_angle;
    
    % Move axis motor and pause appropriately
    axis_angle = 0;
    set_mc_position(axis_angle, AXIS_MOTOR_ID, mySerialObj)
    pause (abs(axis_angle - old_axis_angle)/(360 * 1) * 60 + 1);
    old_axis_angle = axis_angle;
    
    % Move roll motor and pause appropriately
    roll_angle = 0;
    set_mc_position(roll_angle, ROLL_MOTOR_ID, mySerialObj);
    pause (abs(roll_angle - old_roll_angle)/(360 * 10) * 60 + 1);
    old_roll_angle = roll_angle;
end


fprintf('Process Complete.\n');
