function set_mc_position(position, device, s)
%set_mc_position takes a position input, device, and serial object
%   this information is exported to the master of the motor controller and
%   the move to that absolute position is carried out.
%
%   This function supports inputs from -(2^31) to 2^31

    %lookup of device hex address
    dev = devlookup(device);
    
    AXIS_MOTOR_ID = 0;
    ROLL_MOTOR_ID = 1;
    %convert position from degrees to encoder counts
    if (device == ROLL_MOTOR_ID)
        position = (position / 360);            % angle to % rotation
        position = position * (5.5 / 2.1);      % ratio of ball diameters (sphere/output shaft in inches)
        position = position * 39000;            % # encoder counts /revolution of output shaft
        position = floor(position);             % round to integer
    elseif (device == AXIS_MOTOR_ID)
        position = (position / 360);            % angle to % rotation
        position = position * (12 / 0.6);       % ratio of turn table/output shaft in inches
        position = position * 39000;            % # encoder counts /revolution of output shaft
        position = floor(position);             % round to integer
    end
    
    %convert to a string
    str = [dev 'P' dec2hex(position+2^31)];
    
    %transmit string
    for ii = 1:11
        fprintf(s, '%s', str(1,ii));
    end
end