function set_mc_velocity(velocity, device, s)
%set_mc_velocity takes a velocity input, device, and serial object
%   This information is exported to the master of the motor controller and
%   the controller adjusts the velocity to the desired level
%
%   This function supports inputs from -(2^31) to 2^31

    %lookup of device hex address
    dev = devlookup(device);
    
    AXIS_MOTOR_ID = 0;
    ROLL_MOTOR_ID = 1;
    %convert position from degrees to encoder counts
    if (device == ROLL_MOTOR_ID)
        velocity = velocity * (5.5 / 2.1);          % Convert from ball revolutions to output shaft revolutions
        velocity = velocity / 60;                   % Convert to rev/sec
        velocity = velocity * 500E-6;               % Convert to rev/500 microsecond interrupt
        velocity = velocity * 39000;                % Convert to encoder count / 500 microsecond interrrupt
        velocity = round(velocity);                 % And round to an integer
    elseif (device == AXIS_MOTOR_ID)
        velocity = velocity * (12 / 0.6);          % Convert from table revolutins to output shaft revolutions
        velocity = velocity / 60;                   % Convert to rev/sec
        velocity = velocity * 500E-6;               % Convert to rev/500 microsecond interrupt
        velocity = velocity * 39000;                % Convert to encoder count / 500 microsecond interrrupt
        velocity = round(velocity); 
    end
    
    
    %convert to a string
    str = [dev 'V' dec2hex(velocity+2^31)];
    
    %transmit string
    for ii = 1:11
        fprintf(s, '%s', str(1,ii));
    end
end